@@ -220,6 +220,29 @@ class PredictionServiceAsyncClient:
     ) -> prediction_service.PredictResponse:
         r"""Perform an online prediction.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_predict():
+                # Create a client
+                client = aiplatform_v1.PredictionServiceClient()
+
+                # Initialize request argument(s)
+                instances = aiplatform_v1.Value()
+                instances.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1.PredictRequest(
+                    endpoint="endpoint_value",
+                    instances=instances,
+                )
+
+                # Make the request
+                response = client.predict(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.PredictRequest, dict]):
                 The request object. Request message for
@@ -334,6 +357,26 @@ class PredictionServiceAsyncClient:
            [DeployedModel][google.cloud.aiplatform.v1.DeployedModel]
            that served this prediction.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_raw_predict():
+                # Create a client
+                client = aiplatform_v1.PredictionServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.RawPredictRequest(
+                    endpoint="endpoint_value",
+                )
+
+                # Make the request
+                response = client.raw_predict(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.RawPredictRequest, dict]):
                 The request object. Request message for
@@ -492,6 +535,30 @@ class PredictionServiceAsyncClient:
         populated. Only deployed AutoML tabular Models have
         explanation_spec.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_explain():
+                # Create a client
+                client = aiplatform_v1.PredictionServiceClient()
+
+                # Initialize request argument(s)
+                instances = aiplatform_v1.Value()
+                instances.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1.ExplainRequest(
+                    endpoint="endpoint_value",
+                    instances=instances,
+                )
+
+                # Make the request
+                response = client.explain(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ExplainRequest, dict]):
                 The request object. Request message for
