@@ -228,6 +228,35 @@ class VizierServiceAsyncClient:
         r"""Creates a Study. A resource name will be generated
         after creation of the Study.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_create_study():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                study = aiplatform_v1.Study()
+                study.display_name = "display_name_value"
+                study.study_spec.metrics.metric_id = "metric_id_value"
+                study.study_spec.metrics.goal = "MINIMIZE"
+                study.study_spec.parameters.double_value_spec.min_value = 0.96
+                study.study_spec.parameters.double_value_spec.max_value = 0.962
+                study.study_spec.parameters.parameter_id = "parameter_id_value"
+
+                request = aiplatform_v1.CreateStudyRequest(
+                    parent="parent_value",
+                    study=study,
+                )
+
+                # Make the request
+                response = client.create_study(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CreateStudyRequest, dict]):
                 The request object. Request message for
@@ -307,6 +336,25 @@ class VizierServiceAsyncClient:
     ) -> study.Study:
         r"""Gets a Study by name.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_get_study():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetStudyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_study(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetStudyRequest, dict]):
                 The request object. Request message for
@@ -377,6 +425,27 @@ class VizierServiceAsyncClient:
         r"""Lists all the studies in a region for an associated
         project.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_studies():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListStudiesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_studies(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListStudiesRequest, dict]):
                 The request object. Request message for
@@ -458,6 +527,22 @@ class VizierServiceAsyncClient:
     ) -> None:
         r"""Deletes a Study.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_delete_study():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.DeleteStudyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_study(request=request)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeleteStudyRequest, dict]):
                 The request object. Request message for
@@ -524,6 +609,27 @@ class VizierServiceAsyncClient:
         r"""Looks a study up using the user-defined display_name field
         instead of the fully qualified resource name.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_lookup_study():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.LookupStudyRequest(
+                    parent="parent_value",
+                    display_name="display_name_value",
+                )
+
+                # Make the request
+                response = client.lookup_study(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.LookupStudyRequest, dict]):
                 The request object. Request message for
@@ -597,6 +703,32 @@ class VizierServiceAsyncClient:
         long-running operation succeeds, it will contain a
         [SuggestTrialsResponse][google.cloud.ml.v1.SuggestTrialsResponse].
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_suggest_trials():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.SuggestTrialsRequest(
+                    parent="parent_value",
+                    suggestion_count=1744,
+                    client_id="client_id_value",
+                )
+
+                # Make the request
+                operation = client.suggest_trials(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.SuggestTrialsRequest, dict]):
                 The request object. Request message for
@@ -660,6 +792,25 @@ class VizierServiceAsyncClient:
     ) -> study.Trial:
         r"""Adds a user provided Trial to a Study.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_create_trial():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.CreateTrialRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.create_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CreateTrialRequest, dict]):
                 The request object. Request message for
@@ -742,6 +893,25 @@ class VizierServiceAsyncClient:
     ) -> study.Trial:
         r"""Gets a Trial.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_get_trial():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.GetTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.GetTrialRequest, dict]):
                 The request object. Request message for
@@ -816,6 +986,26 @@ class VizierServiceAsyncClient:
     ) -> pagers.ListTrialsAsyncPager:
         r"""Lists the Trials associated with a Study.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_trials():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListTrialsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_trials(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListTrialsRequest, dict]):
                 The request object. Request message for
@@ -898,6 +1088,26 @@ class VizierServiceAsyncClient:
         Trial. This measurement is assumed to have been taken
         before the Trial is complete.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_add_trial_measurement():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.AddTrialMeasurementRequest(
+                    trial_name="trial_name_value",
+                )
+
+                # Make the request
+                response = client.add_trial_measurement(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.AddTrialMeasurementRequest, dict]):
                 The request object. Request message for
@@ -952,6 +1162,25 @@ class VizierServiceAsyncClient:
     ) -> study.Trial:
         r"""Marks a Trial as complete.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_complete_trial():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.CompleteTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.complete_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CompleteTrialRequest, dict]):
                 The request object. Request message for
@@ -1005,6 +1234,22 @@ class VizierServiceAsyncClient:
     ) -> None:
         r"""Deletes a Trial.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_delete_trial():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.DeleteTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_trial(request=request)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.DeleteTrialRequest, dict]):
                 The request object. Request message for
@@ -1071,6 +1316,30 @@ class VizierServiceAsyncClient:
         will contain a
         [CheckTrialEarlyStoppingStateResponse][google.cloud.ml.v1.CheckTrialEarlyStoppingStateResponse].
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_check_trial_early_stopping_state():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.CheckTrialEarlyStoppingStateRequest(
+                    trial_name="trial_name_value",
+                )
+
+                # Make the request
+                operation = client.check_trial_early_stopping_state(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.CheckTrialEarlyStoppingStateRequest, dict]):
                 The request object. Request message for
@@ -1134,6 +1403,25 @@ class VizierServiceAsyncClient:
     ) -> study.Trial:
         r"""Stops a Trial.
 
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_stop_trial():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.StopTrialRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.stop_trial(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.StopTrialRequest, dict]):
                 The request object. Request message for
@@ -1190,6 +1478,26 @@ class VizierServiceAsyncClient:
         pareto-optimal can be checked in wiki page.
         https://en.wikipedia.org/wiki/Pareto_efficiency
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1
+
+            def sample_list_optimal_trials():
+                # Create a client
+                client = aiplatform_v1.VizierServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1.ListOptimalTrialsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                response = client.list_optimal_trials(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1.types.ListOptimalTrialsRequest, dict]):
                 The request object. Request message for
