@@ -487,6 +487,36 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Creates a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_dataset():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                dataset = aiplatform_v1beta1.Dataset()
+                dataset.display_name = "display_name_value"
+                dataset.metadata_schema_uri = "metadata_schema_uri_value"
+                dataset.metadata.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1beta1.CreateDatasetRequest(
+                    parent="parent_value",
+                    dataset=dataset,
+                )
+
+                # Make the request
+                operation = client.create_dataset(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreateDatasetRequest, dict]):
                 The request object. Request message for
@@ -577,6 +607,26 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> dataset.Dataset:
         r"""Gets a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_dataset():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetDatasetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_dataset(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetDatasetRequest, dict]):
                 The request object. Request message for
@@ -649,6 +699,31 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gca_dataset.Dataset:
         r"""Updates a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_update_dataset():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                dataset = aiplatform_v1beta1.Dataset()
+                dataset.display_name = "display_name_value"
+                dataset.metadata_schema_uri = "metadata_schema_uri_value"
+                dataset.metadata.null_value = "NULL_VALUE"
+
+                request = aiplatform_v1beta1.UpdateDatasetRequest(
+                    dataset=dataset,
+                )
+
+                # Make the request
+                response = client.update_dataset(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UpdateDatasetRequest, dict]):
                 The request object. Request message for
@@ -737,6 +812,27 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> pagers.ListDatasetsPager:
         r"""Lists Datasets in a Location.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_datasets():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListDatasetsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_datasets(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListDatasetsRequest, dict]):
                 The request object. Request message for
@@ -817,6 +913,30 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Deletes a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_dataset():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteDatasetRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_dataset(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteDatasetRequest, dict]):
                 The request object. Request message for
@@ -911,6 +1031,35 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Imports data into a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_import_data():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                import_configs = aiplatform_v1beta1.ImportDataConfig()
+                import_configs.gcs_source.uris = ['uris_value_1', 'uris_value_2']
+                import_configs.import_schema_uri = "import_schema_uri_value"
+
+                request = aiplatform_v1beta1.ImportDataRequest(
+                    name="name_value",
+                    import_configs=import_configs,
+                )
+
+                # Make the request
+                operation = client.import_data(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ImportDataRequest, dict]):
                 The request object. Request message for
@@ -1005,6 +1154,34 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Exports data from a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_export_data():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                export_config = aiplatform_v1beta1.ExportDataConfig()
+                export_config.gcs_destination.output_uri_prefix = "output_uri_prefix_value"
+
+                request = aiplatform_v1beta1.ExportDataRequest(
+                    name="name_value",
+                    export_config=export_config,
+                )
+
+                # Make the request
+                operation = client.export_data(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ExportDataRequest, dict]):
                 The request object. Request message for
@@ -1097,6 +1274,27 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> pagers.ListDataItemsPager:
         r"""Lists DataItems in a Dataset.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_data_items():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListDataItemsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_data_items(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListDataItemsRequest, dict]):
                 The request object. Request message for
@@ -1178,6 +1376,26 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> annotation_spec.AnnotationSpec:
         r"""Gets an AnnotationSpec.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_annotation_spec():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetAnnotationSpecRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_annotation_spec(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetAnnotationSpecRequest, dict]):
                 The request object. Request message for
@@ -1250,6 +1468,27 @@ class DatasetServiceClient(metaclass=DatasetServiceClientMeta):
     ) -> pagers.ListAnnotationsPager:
         r"""Lists Annotations belongs to a dataitem
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_annotations():
+                # Create a client
+                client = aiplatform_v1beta1.DatasetServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListAnnotationsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_annotations(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListAnnotationsRequest, dict]):
                 The request object. Request message for
