@@ -437,6 +437,34 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Creates an IndexEndpoint.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_create_index_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                index_endpoint = aiplatform_v1beta1.IndexEndpoint()
+                index_endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1beta1.CreateIndexEndpointRequest(
+                    parent="parent_value",
+                    index_endpoint=index_endpoint,
+                )
+
+                # Make the request
+                operation = client.create_index_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.CreateIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -528,6 +556,26 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> index_endpoint.IndexEndpoint:
         r"""Gets an IndexEndpoint.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_get_index_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.GetIndexEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_index_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.GetIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -601,6 +649,27 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> pagers.ListIndexEndpointsPager:
         r"""Lists IndexEndpoints in a Location.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_list_index_endpoints():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.ListIndexEndpointsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_index_endpoints(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.ListIndexEndpointsRequest, dict]):
                 The request object. Request message for
@@ -683,6 +752,29 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> gca_index_endpoint.IndexEndpoint:
         r"""Updates an IndexEndpoint.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_update_index_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                index_endpoint = aiplatform_v1beta1.IndexEndpoint()
+                index_endpoint.display_name = "display_name_value"
+
+                request = aiplatform_v1beta1.UpdateIndexEndpointRequest(
+                    index_endpoint=index_endpoint,
+                )
+
+                # Make the request
+                response = client.update_index_endpoint(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UpdateIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -766,6 +858,30 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
     ) -> gac_operation.Operation:
         r"""Deletes an IndexEndpoint.
 
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_delete_index_endpoint():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.DeleteIndexEndpointRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_index_endpoint(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeleteIndexEndpointRequest, dict]):
                 The request object. Request message for
@@ -862,6 +978,36 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         DeployedIndex within it.
         Only non-empty Indexes can be deployed.
 
+
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_deploy_index():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                deployed_index = aiplatform_v1beta1.DeployedIndex()
+                deployed_index.id = "id_value"
+                deployed_index.index = "index_value"
+
+                request = aiplatform_v1beta1.DeployIndexRequest(
+                    index_endpoint="index_endpoint_value",
+                    deployed_index=deployed_index,
+                )
+
+                # Make the request
+                operation = client.deploy_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.DeployIndexRequest, dict]):
                 The request object. Request message for
@@ -960,6 +1106,32 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         DeployedIndex from it, and freeing all resources it's
         using.
 
+
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_undeploy_index():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                request = aiplatform_v1beta1.UndeployIndexRequest(
+                    index_endpoint="index_endpoint_value",
+                    deployed_index_id="deployed_index_id_value",
+                )
+
+                # Make the request
+                operation = client.undeploy_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.UndeployIndexRequest, dict]):
                 The request object. Request message for
@@ -1057,6 +1229,36 @@ class IndexEndpointServiceClient(metaclass=IndexEndpointServiceClientMeta):
         r"""Update an existing DeployedIndex under an
         IndexEndpoint.
 
+
+
+        .. code-block::
+
+            from google.cloud import aiplatform_v1beta1
+
+            def sample_mutate_deployed_index():
+                # Create a client
+                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+
+                # Initialize request argument(s)
+                deployed_index = aiplatform_v1beta1.DeployedIndex()
+                deployed_index.id = "id_value"
+                deployed_index.index = "index_value"
+
+                request = aiplatform_v1beta1.MutateDeployedIndexRequest(
+                    index_endpoint="index_endpoint_value",
+                    deployed_index=deployed_index,
+                )
+
+                # Make the request
+                operation = client.mutate_deployed_index(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.aiplatform_v1beta1.types.MutateDeployedIndexRequest, dict]):
                 The request object. Request message for
